Skip to contents

This module produces ggplot2::ggplot() type individual patient plots that display trends in parameter values over time for each patient, using data with ADaM structure.

Usage

tm_g_ipp(
  label,
  dataname,
  parentname = "ADSL",
  arm_var,
  paramcd,
  id_var = teal.picks::variables("USUBJID", "USUBJID", fixed = TRUE),
  visit_var = teal.picks::variables("AVISIT", "AVISIT", fixed = TRUE),
  aval_var = teal.picks::variables("AVAL", "AVAL", fixed = TRUE),
  avalu_var = teal.picks::variables("AVALU", "AVALU", fixed = TRUE),
  baseline_var = teal.picks::variables("BASE", "BASE", fixed = TRUE),
  add_baseline_hline = FALSE,
  separate_by_obs = FALSE,
  suppress_legend = FALSE,
  add_avalu = TRUE,
  plot_height = c(1200L, 400L, 5000L),
  plot_width = NULL,
  pre_output = NULL,
  post_output = NULL,
  ggplot2_args = teal.widgets::ggplot2_args(),
  transformators = list(),
  decorators = list()
)

Arguments

label

(character)
menu item label of the module in the teal app.

dataname

(character)
analysis data used in teal module.

parentname

(character)
parent analysis data used in teal module, usually this refers to ADSL.

arm_var

(teal.picks::variables(), teal.picks::picks(), or legacy choices_selected)
Required (no default, as on main). Arm encoding; resolved on parentname (typically ADSL). Legacy inputs are coerced with a deprecation warning.

paramcd

(teal.picks::picks() or legacy choices_selected from teal.transform::value_choices())
Required (no default, as on main). Parameter code filter: a teal.picks::picks() with teal.picks::variables() (typically PARAMCD) and teal.picks::values() for levels; legacy choices_selected inputs are coerced with a deprecation warning.

id_var,

visit_var, aval_var, avalu_var, baseline_var (teal.picks::variables(), teal.picks::picks(), or legacy choices_selected)
encodings on dataname. Legacy inputs are coerced with a deprecation warning.

visit_var

(teal.picks::variables(); legacy teal.transform objects are deprecated but still accepted)
object with all available choices and preselected option for variable names that can be used as visit variable. Must be a factor in dataname.

aval_var

(teal.picks::variables(); legacy teal.transform objects are deprecated but still accepted)
object with all available choices and pre-selected option for the analysis variable.

avalu_var

(teal.picks::variables(); legacy teal.transform objects are deprecated but still accepted)
object with all available choices and preselected option for the analysis unit variable.

baseline_var

(teal.picks::variables(); legacy teal.transform objects are deprecated but still accepted)
object with all available choices and preselected option for variable values that can be used as baseline_var.

add_baseline_hline

(logical)
whether a horizontal line should be added to the plot at baseline y-value.

separate_by_obs

(logical)
whether to create multi-panel plots.

suppress_legend

(logical)
whether to suppress the plot legend.

add_avalu

(logical)
whether avalu_first text should be appended to the plot title and y-axis label.

plot_height

(numeric) optional
vector of length three with c(value, min, max). Specifies the height of the main plot and renders a slider on the plot to interactively adjust the plot height.

plot_width

(numeric) optional
vector of length three with c(value, min, max). Specifies the width of the main plot and renders a slider on the plot to interactively adjust the plot width.

pre_output

(shiny.tag) optional,
with text placed before the output to put the output into context. For example a title.

post_output

(shiny.tag) optional,
with text placed after the output to put the output into context. For example the shiny::helpText() elements are useful.

ggplot2_args

(ggplot2_args) optional
object created by teal.widgets::ggplot2_args() with settings for the module plot. For this module, this argument will only accept ggplot2_args object with labs list of the following child elements: title, subtitle, x, y. No other elements are taken into account. The argument is merged with option teal.ggplot2_args and with default module arguments (hard coded in the module body).

For more details, see the vignette: vignette("custom-ggplot2-arguments", package = "teal.widgets").

transformators

(list of teal_transform_module) that will be applied to transform module's data input. To learn more check vignette("transform-input-data", package = "teal").

decorators

[Experimental] (named list of lists of teal_transform_module) optional, decorator for tables or plots included in the module output reported. The decorators are applied to the respective output objects.

See section "Decorating Module" below for more details.

Value

a teal_module object.

Decorating Module

This module generates the following objects, which can be modified in place using decorators:

  • plot (ggplot)

A Decorator is applied to the specific output using a named list of teal_transform_module objects. The name of this list corresponds to the name of the output to which the decorator is applied. See code snippet below:

tm_g_ipp(
   ..., # arguments for module
   decorators = list(
     plot = teal_transform_module(...) # applied only to `plot` output
   )
)

For additional details and examples of decorators, refer to the vignette vignette("decorate-module-output", package = "teal.modules.clinical").

To learn more please refer to the vignette vignette("transform-module-output", package = "teal") or the teal::teal_transform_module() documentation.

Reporting

This module returns an object of class teal_module, that contains a server function. Since the server function returns a teal_report object, this makes this module reportable, which means that the reporting functionality will be turned on automatically by the teal framework.

For more information on reporting in teal, see the vignettes:

See also

The TLG Catalog where additional example apps implementing this module can be found.

Examples in Shinylive

example-1

Open in Shinylive

Examples

library(nestcolor)

data <- teal_data()
data <- within(data, {
  library(teal.modules.clinical)
  library(tern)
  library(dplyr)
  ADSL <- tmc_ex_adsl %>%
    slice(1:20) %>%
    df_explicit_na()
  ADLB <- tmc_ex_adlb %>%
    filter(USUBJID %in% ADSL$USUBJID) %>%
    df_explicit_na() %>%
    filter(AVISIT != "SCREENING")
})
join_keys(data) <- default_cdisc_join_keys[names(data)]

ADSL <- data[["ADSL"]]
ADLB <- data[["ADLB"]]

app <- init(
  data = data,
  modules = modules(
    tm_g_ipp(
      label = "Individual Patient Plot",
      dataname = "ADLB",
      parentname = "ADSL",
      arm_var = variables(c("ARMCD", "ARM"), "ARMCD"),
      paramcd = picks(
        datasets("ADLB", "ADLB"),
        variables("PARAMCD", "PARAMCD"),
        values(selected = "ALT", multiple = FALSE)
      ),
      id_var = variables("USUBJID", "USUBJID"),
      visit_var = variables("AVISIT", "AVISIT"),
      aval_var = variables(c("AVAL", "CHG"), "AVAL"),
      avalu_var = variables("AVALU", "AVALU"),
      baseline_var = variables("BASE", "BASE"),
      add_baseline_hline = FALSE,
      separate_by_obs = FALSE
    )
  )
)
#> Initializing tm_g_ipp
#> Warning: rlang::dots_list(..., .ignore_empty = "trailing")
#>  - Setting explicit `selected` while `choices` are delayed (set using `tidyselect`) doesn't guarantee that `selected` is a subset of `choices`.
if (interactive()) {
  shinyApp(app$ui, app$server)
}