Creates a valid expression to generate a survival forest plot.
template_forest_tte(
dataname = "ANL",
parentname = "ANL_ADSL",
arm_var,
ref_arm = NULL,
comp_arm = NULL,
obj_var_name = "",
aval_var = "AVAL",
cnsr_var = "CNSR",
subgroup_var,
strata_var = NULL,
conf_level = 0.95,
col_symbol_size = NULL,
time_unit_var = "AVALU",
ggplot2_args = teal.widgets::ggplot2_args()
)a list of expressions to generate a table or plot object.
(character)
analysis data used in teal module.
(character)
parent analysis data used in teal module, usually this refers to ADSL.
(character)
variable names that can be used as arm_var.
(character)
the level of reference arm in case of arm comparison.
(character)
the level of comparison arm in case of arm comparison.
(character)
additional text to append to the table title.
(character)
name of the analysis value variable.
(character)
name of the censoring variable.
(character)
with variable names that can be used as subgroups.
(character)
names of the variables for stratified analysis.
(numeric)
value for the confidence level within the range of (0, 1).
(integer or NULL)
column index to be used to determine relative size for
estimator plot symbol. Typically, the symbol size is proportional to the sample size used
to calculate the estimator. If NULL, the same symbol size is used for all subgroups.
(character)
name of the variable representing time units.
optional, (ggplot2_args)
object created by teal.widgets::ggplot2_args() with settings
for the module plot. The argument is merged with option teal.ggplot2_args and with default module arguments
(hard coded in the module body).
For more details, see the vignette: vignette("custom-ggplot2-arguments", package = "teal.widgets").
tm_g_forest_tte()