- label
(character)
menu item label of the module in the teal app.
- dataname
(character)
analysis data used in teal module.
- parentname
(character)
parent analysis data used in teal module, usually this refers to ADSL.
- aval_var
(teal.transform::choices_selected())
object with
all available choices and pre-selected option for the analysis variable.
- id_var
(teal.transform::choices_selected())
object specifying
the variable name for subject id.
- arm_var
(teal.transform::choices_selected())
object with all
available choices and preselected option for variable names that can be used as arm_var.
It defines the grouping variable(s) in the results table.
If there are two elements selected for arm_var,
second variable will be nested under the first variable.
- visit_var
(teal.transform::choices_selected())
object with
all available choices and preselected option for variable names that can be used as visit variable.
Must be a factor in dataname.
- cov_var
(teal.transform::choices_selected())
object with all
available choices and preselected option for the covariates variables.
- arm_ref_comp
optional, (list)
If specified it must be a named list with each element corresponding to
an arm variable in ADSL and the element must be another list (possibly
with delayed teal.transform::variable_choices() or delayed teal.transform::value_choices()
with the elements named ref and comp that the defined the default
reference and comparison arms when the arm variable is changed.
- paramcd
(teal.transform::choices_selected())
object with all
available choices and preselected option for the parameter code variable from dataname.
- method
(teal.transform::choices_selected())
object with
all available choices and pre-selected option for the adjustment method.
- conf_level
(teal.transform::choices_selected())
object with
all available choices and pre-selected option for the confidence level, each within range of (0, 1).
- plot_height
optional, (numeric)
a vector of length three with c(value, min, max). Specifies the
height of the main plot and renders a slider on the plot to interactively adjust the plot height.
- plot_width
optional, (numeric)
a vector of length three with c(value, min, max). Specifies the width
of the main plot and renders a slider on the plot to interactively adjust the plot width.
- total_label
(string)
string to display as total column/row label if column/row is
enabled (see add_total). Defaults to "All Patients". To set a new default total_label to
apply in all modules, run set_default_total_label("new_default").
- pre_output
optional, (shiny.tag)
with text placed before the output to put the output into context.
For example a title.
- post_output
optional, (shiny.tag)
with text placed after the output to put the output into context.
For example the shiny::helpText() elements are useful.
- basic_table_args
optional, (basic_table_args)
object created by teal.widgets::basic_table_args()
with settings for the module table. The argument is merged with option teal.basic_table_args and with default
module arguments (hard coded in the module body).
For more details, see the vignette: vignette("custom-basic-table-arguments", package = "teal.widgets").
- ggplot2_args
(ggplot2_args)
optional, object created by teal.widgets::ggplot2_args()
with settings for all the plots or named list of ggplot2_args objects for plot-specific settings.
List names should match the following: c("default", "lsmeans", "diagnostic"). The argument is merged
with option teal.ggplot2_args and with default module arguments (hard coded in the module body).
For more details, see the help vignette: vignette("custom-ggplot2-arguments", package = "teal.widgets").